#
# CHMPX
#
# Copyright 2014 Yahoo Japan corporation.
#
# CHMPX is inprocess data exchange by MQ with consistent hashing.
# CHMPX is made for the purpose of the construction of
# original messaging system and the offer of the client
# library.
# CHMPX transfers messages between the client and the server/
# slave. CHMPX based servers are dispersed by consistent
# hashing and are automatically laid out. As a result, it
# provides a high performance, a high scalability.
#
# For the full copyright and license information, please view
# the license file that was distributed with this source code.
#
# AUTHOR:   Takeshi Nakatani
# CREATE:   Fri 17 Jul 2016
# REVISION:
#

#
# Local macros/define
#
%if %{undefined package_revision}
%global package_revision 1
%endif

%if %{undefined make_build}
%global make_build %{__make} %{?_smp_mflags}
%endif

%if %{undefined autosetup}
%global autosetup %setup -q
%endif

%global gittag v1.0.75

%if %{undefined make_check}
%global make_check 1
%endif

#
# main package
#
Summary: Consistent Hashing Mq inProcess data eXchange
Name: chmpx
Version: 1.0.75
Release: %{package_revision}%{?dist}
License: MIT
Group: Applications/Communications
URL: https://github.com/yahoojapan/chmpx
Source0: https://github.com/yahoojapan/chmpx/archive/%{gittag}/%{name}-%{version}.tar.gz
Requires: k2hash%{?_isa} >= 1.0.74, libfullock%{?_isa} >= 1.0.36
BuildRequires: git-core gcc-c++ make libtool k2hash-devel >= 1.0.74, libfullock-devel >= 1.0.36

%description
CHMPX is Consistent Hashing Mq inProcess data eXchange system, and
libraries for clients by Yahoo! JAPAN.
CHMPX is made for the purpose of the construction of original messaging
system and the offer of the client library. CHMPX transfers messages
between the client and the server/slave. CHMPX based servers are dis-
persed by consistent hashing and are automatically laid out. As a
result, it provides a high performance, a high scalability.

CHMPX is following specifications:
- Build up cluster with uniq name by some servers.
- Layouts servers in cluster by consistent hashing.
- Supports interprocess communication across the servers.
- Supports synchronous/asynchronous communication.
- Supports communicating messages in the target specified(HASH).
- Supports plugin Hashing function for target messaging.(k2hash)
- Supports communicating messages in the random.
- Supports SSL communication.
- The message communication possible bypass.
- No message lost during communication failure.
- Broadcast a message communication possible.
- Provision of high-level library for clients.
- Supports multi-thread/process for client programs.

%prep
%autosetup -n %{name}-%{version}

%build
./autogen.sh
%configure --disable-static --with-nss
%make_build

%install
%make_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'

%if %{make_check}
%check
%{__make} check
%endif

%if %{defined ldconfig_scriptlets}
%ldconfig_scriptlets
%else
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%if 0%{?rhel} == 6
%clean
rm -rf %{buildroot}
%endif

%files
%if 0%{?rhel} == 6
%doc COPYING
%defattr(-,root,root)
%else
%license COPYING
%endif
%doc README AUTHORS ChangeLog
%{_libdir}/*.so.1*
%{_mandir}/man1/*
%{_bindir}/*

#
# devel package
#
%package devel
Summary: Consistent Hashing Mq inProcess data eXchange (development)
Requires: %{name}%{?_isa} = %{version}-%{release}, k2hash-devel%{?_isa} >= 1.0.74, libfullock-devel%{?_isa} >= 1.0.36

%description devel
Development package for building with chmpx shared library.
This package has header files and symbols for it.

%files devel
%if 0%{?rhel} == 6
%defattr(-,root,root)
%endif
%doc README AUTHORS ChangeLog
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Tue Jun 09 2020 Takeshi Nakatani <ggtakec@gmail.com>   1.0.75-1
- Added checking resolv for hostname - #45

* Fri Apr 03 2020 Takeshi Nakatani <ggtakec@gmail.com>   1.0.74
- Fixed bugs about reverse peer and etc - #43
- Changed to not check expiration date in merge process - #42
- Fixed code for cppcheck 1.90 - #41

* Tue Dec 24 2019 Takeshi Nakatani <ggtakec@gmail.com>   1.0.73
- Fixed a bug about complete auto merging - #38

* Fri Dec 20 2019 Takeshi Nakatani <ggtakec@gmail.com>   1.0.72
- Fixed a bug and updated version of dependency packages - #36

* Fri Dec 20 2019 Takeshi Nakatani <ggtakec@gmail.com>   1.0.71
- Enhanced feature about IPv6 and NAT support - #34

* Mon Dec 02 2019 Takeshi Nakatani <ggtakec@gmail.com>   1.0.70
- Host matching improvements and fixes bugs - #32
- Enhanced node discovery of hostnames and IP addresses - #31

* Mon Mar 25 2019 Takeshi Nakatani <ggtakec@gmail.com>   1.0.69
- Updated chmpxstatus man page - #28
- Added status wait mode to chmpxstatus command - #27

* Tue Mar 12 2019 Takeshi Nakatani <ggtakec@gmail.com>   1.0.68
- Fixed codes for cppcheck 1.87 - #23

* Thu Jan 17 2019 Takeshi Nakatani <ggtakec@gmail.com>   1.0.67
- Fixed misspelling, and etc - #20
- Added check using cppcheck - #19
- Reflected the spelling check result for all sources - #18

* Wed Dec 26 2018 Takeshi Nakatani <ggtakec@gmail.com>   1.0.66
- Fixed build warning about comparison of pointer with integer

* Tue Dec 11 2018 Takeshi Nakatani <ggtakec@gmail.com>   1.0.65
- Updated common build tool files

* Wed Dec 05 2018 Takeshi Nakatani <ggtakec@gmail.com>   1.0.64
- Fixed some compile warnings and updated AUTHOR
- Changed to strict packaging and changed documents

* Wed Oct 17 2018 Takeshi Nakatani <ggtakec@gmail.com>   1.0.63
- Fixed spec file and updated dependency

* Mon Jul 02 2018 Takeshi Nakatani <ggtakec@gmail.com>   1.0.62
- avoid static object initialization order problem(SIOF)

* Tue Jun 26 2018 Takeshi Nakatani <ggtakec@gmail.com>   1.0.61
- Fixed bugs about implementation some functions, etc

* Thu Jun 21 2018 Takeshi Nakatani <ggtakec@gmail.com>   1.0.60
- Supports multiple SSL/TLS libraries and associated implementation

* Thu May 17 2018 Takeshi Nakatani <ggtakec@gmail.com>   1.0.59
- Cleanup credit comments in sources and Modified etc
- Changed build logic to new for rpm/debian packaging
- Fixed filename typo from make_valiables.sh to make_variables.sh
- Fixed build error with openssl 1.1.0

* Mon Mar 26 2018 Takeshi Nakatani <ggtakec@gmail.com>   1.0.58
- Update dependency on k2hash v1.0.57

* Fri Mar 23 2018 Takeshi Nakatani <ggtakec@gmail.com>   1.0.57
- Improved the appearance of chmpxlinetool
- Added chmpxlinetool and changed some logic/codes, fixed bugs

* Tue Mar 13 2018 Takeshi Nakatani <ggtakec@gmail.com>   1.0.56
- Fixed bugs about connecting SSL and invalid result on ctlport

* Wed Mar 07 2018 Takeshi Nakatani <ggtakec@gmail.com>   1.0.55
- Fixed bugs about status and updating status flow etc

* Tue Feb 27 2018 Takeshi Nakatani <ggtakec@gmail.com>   1.0.54
- Enhanced status and status flow and Fixed bugs about status

* Tue Feb 13 2018 Takeshi Nakatani <ggtakec@gmail.com>   1.0.53
- Force to set SERVICE OUT/DOWN status when all server chmpx down

* Tue Mar 28 2017 Takeshi Nakatani <ggtakec@gmail.com>   1.0.52
- Updated fullock and k2hash submodule version
- Updated k2hash submodule v1.0.56
- Updated fullock submodule v1.0.24
- Added lib_version_for_link option to make_valiables.sh

* Tue Feb 14 2017 Takeshi Nakatani <ggtakec@gmail.com>   1.0.51
- Updated dependency for fixing bugs in libfullock
- Fixed error/warning for compiling and changed travis.yaml - #2

* Wed Dec 07 2016 Takeshi Nakatani <ggtakec@gmail.com>   1.0.50
- First version of open sorce on Github
